@@ -52,6 +52,10 @@ class CallChannel(
 				"InitialVideo": self.initial_video,
 			},
 		)
+		self._add_immutables({
+			'InitialAudio': telepathy.interfaces.CHANNEL_TYPE_STREAMED_MEDIA,
+			'InitialVideo': telepathy.interfaces.CHANNEL_TYPE_STREAMED_MEDIA,
+		})
 		self._implement_property_get(
 			telepathy.interfaces.CHANNEL_INTERFACE,
 			{
@@ -59,6 +63,10 @@ class CallChannel(
 				'InitiatorID': lambda: self._initiator.name,
 			},
 		)
+		self._add_immutables({
+			'InitiatorHandle': telepathy.interfaces.CHANNEL_INTERFACE,
+			'InitiatorID': telepathy.interfaces.CHANNEL_INTERFACE,
+		})
 
 		self.GroupFlagsChanged(0, 0)
 		self.MembersChanged(
@@ -128,7 +136,7 @@ class CallChannel(
 		self._conn.session.backend.call(contactNumber)
 
 		streamId = 0
-		streamState = telepathy.constants.MEDIA_STREAM_STATE_DISCONNECTED
+		streamState = telepathy.constants.MEDIA_STREAM_STATE_CONNECTED
 		streamDirection = telepathy.constants.MEDIA_STREAM_DIRECTION_BIDIRECTIONAL
 		pendingSendFlags = telepathy.constants.MEDIA_STREAM_PENDING_REMOTE_SEND
 		return [(streamId, contact, streamTypes[0], streamState, streamDirection, pendingSendFlags)]
