@@ -15,10 +15,6 @@ _moduleLogger = logging.getLogger("channel.text")
 
 
 class DebugPromptChannel(tp.ChannelTypeText, cmd.Cmd):
-	"""
-	@todo Look into implementing ChannelInterfaceMessages for rich text formatting
-	@todo Add a command that initiates a file transfer, giving the log file to the user
-	"""
 
 	def __init__(self, connection, manager, props, contactHandle):
 		self.__manager = manager
