@@ -1,10 +1,5 @@
 #!/usr/bin/env python
 
-"""
-@todo Look into supporting more states for more granular selection of updates
-@todo Could make another state that depends on whether there are open channels or not
-"""
-
 import logging
 
 import gobject
